#
# spec file for package plantuml
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plantuml
Version:        1.2020.9
Release:        bp156.3.8
Summary:        Java UML Tool
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/Other
URL:            http://plantuml.sourceforge.net
Source0:        https://github.com/plantuml/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.script
Source2:        %{name}.xml
Source10:       example01.uml
Source11:       example02.uml
Source20:       http://plantuml.com/PlantUML_Language_Reference_Guide.pdf
BuildRequires:  ant
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  java-devel >= 1.5
BuildRequires:  jpackage-utils
BuildRequires:  libxslt
BuildRequires:  unzip
Requires:       dejavu-fonts
Requires:       java >= 1.8.0
Requires:       jpackage-utils
Conflicts:      java-1_5_0-gcj-compat
BuildArch:      noarch

%description
PlantUML is a program allowing to draw UML diagrams, using a simple human readable text description.

PlantUML supports the following diagram types:
   - sequence diagram
   - use case diagram
   - class diagram
   - activity diagram
   - component diagram
   - state diagram

Output images can be generated in PNG, in SVG or LaTeX format.  PlantUML also supports generation of ASCII art diagrams (only for sequence diagrams).

%prep
%setup -q
# Replace placeholder strings:
cp %{SOURCE1} %{name}
cp %{SOURCE2} .
cp %{SOURCE10} %{SOURCE11} .
cp %{SOURCE20} .

%build
%{ant} \
  -Dant.build.javac.source=1.6 \
  -Dant.build.javac.target=1.6

# Building Manpages and HTML:
DB=%{_datadir}/xml/docbook/stylesheet/nwalsh/current/
xsltproc $DB/manpages/docbook.xsl %{name}.xml
xsltproc --output %{name}.html $DB/html/docbook.xsl %{name}.xml

%install
install -m 755 -d %{buildroot}%{_bindir}/
install -m 755 -d %{buildroot}%{_javadir}
install -m 755 -d %{buildroot}%{_mandir}/man1
install -m 755 %{name} %{buildroot}%{_bindir}/%{name}
install -m 644 %{name}.1  %{buildroot}%{_mandir}/man1/

# Install jar file
cp %{name}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

%files
%license license.txt
%doc example*.uml *.pdf *.html
%{_javadir}/%{name}.jar
%{_javadir}/%{name}-%{version}.jar
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sun May 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.9
  See http://plantuml.com/de/changes for all changes
* Tue Apr 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.8
  See http://plantuml.com/de/changes for all changes
* Mon Apr  6 2020 Andreas Hasenkopf <ahasenkopf@suse.com>
- Added requirement 'dejavu-fonts'
* Sun Apr  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.6
  See http://plantuml.com/de/changes for all changes
* Wed Dec 11 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.13
  See http://plantuml.com/de/changes for all changes
* Wed Nov  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.12
  See http://plantuml.com/de/changes for all changes
* Sun Sep 22 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.11
  See http://plantuml.com/de/changes for all changes
* Mon Sep 16 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.10
  See http://plantuml.com/de/changes for all changes
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.9
  See http://plantuml.com/de/changes for all changes
* Mon May 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.6
  See http://plantuml.com/de/changes for all changes
* Mon Apr 29 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream version 1.2019.4
- Restore original changelog entries
* Fri Feb  8 2019 ahasenkopf@suse.com
- Fixed package internal issues
* Fri Jan 11 2019 ahasenkopf@suse.com
- First commit for version 1.2018.14
* Tue Sep  4 2018 mardnh@gmx.de
- Update to new upstream version 1.2018.10
- Run spec-cleander
* Tue Aug 25 2015 michiel.vanderwulp@gmail.com
- Improve the man page
* Thu Aug 20 2015 michiel.vanderwulp@gmail.com
- Update to PlantUML 8029
* Fri Jun  5 2015 michiel.vanderwulp@gmail.com
- Update to PlantUML 8025
* Sun Sep  4 2011 toms@suse.de
- Initial version 7177
